@@ -42,14 +42,14 @@ sub remove_extension {
    $self->remove_forward ($ext);
 }
 
-=item B<disco_features>
+=item B<disco_feature>
 
 This method can be overwritten by the extension and should return
 a list of namespace URIs of the features that the extension enables.
 
 =cut
 
-sub disco_features { }
+sub disco_feature { }
 
 =back
 
